import os.path
from collections import namedtuple

from charmhelpers.core.hookenv import (
    Config,
    CRITICAL,
    ERROR,
    WARNING,
    INFO,
    DEBUG,
)

LEVELS = (CRITICAL, ERROR, WARNING, INFO, DEBUG)


class HookenvStub:
    """Testable stub for charmhelpers.core.hookenv."""

    def __init__(self, charm_dir):
        self.messages = []
        self.port = None
        self._config = Config()
        self._charm_dir = charm_dir
        self.action_messages = []
        self.action_details = []
        self.statuses = []

    def config(self):
        return self._config

    def charm_dir(self):
        return self._charm_dir

    def log(self, message, level=None):
        if level is not None:
            assert level in LEVELS
        self.messages.append((message, level))

    def open_port(self, port):
        self.port = port

    def action_fail(self, message):
        self.action_messages.append(message)

    def action_set(self, details):
        self.action_details.append(details)

    def status_set(self, status, message):
        self.statuses.append((status, message.decode("utf-8")))

    def local_unit(self):
        return os.path.basename(self._charm_dir) + "/0"


Update = namedtuple("Update", ["fatal"])
Install = namedtuple("Install", ["packages", "options", "fatal"])


class FetchStub:
    """Testable stub for charmhelpers.fetch."""

    def __init__(self, needs_update=False):
        self.needs_update = needs_update
        self.updates = []
        self.installs = []
        self.package_status = {}
        self.sources = []

    def apt_update(self, fatal=False):
        self.needs_update = False
        self.updates.append(Update(fatal))

    def apt_install(self, packages, options=None, fatal=False):
        if self.needs_update:
            raise AssertionError("APT cache wasn't updated.")
        for package in packages:
            self.package_status[package] = "install"
        self.installs.append(Install(packages, options, fatal))

    def add_source(self, url, key=None):
        self.sources.append((url, key))
